Plots for pharmacometrics
See the pm_theme() help topic for functions you
can use to replicate the look and feel of plots generated
by this package.
Basic plots
Residuals versus time
Residuals versus PRED
Residuals versus covariates
NPDE plots
Pairs plots
QQ plots
Histograms
List plots
Faceted plots
Standard paneled displays
Other plots
Layers
combinations: layer_sa(), layer_sh()
Customization
Arrangement
Labeling
pm_gg_labs(), pm_relabel() - for several aesthetics on arbitrary gg plots
pmp_relabel_wrap() - relabel facet strip labels in wrap plots
pmp_relabel_pairs() - relabel strip and axis labels in pairs plots
relabel_at() - relabel plots in a list by name
pm_label_columns(), pm_label_rm() - add or remove labels to data sets
pm_label_break() - labeller for wrapping strip text at a character width
Column names and aliases
Example data sets