R/utils.R
str_break.Rd
Add a single newline to break a string across two lines
str_break(x, width = Inf)
a string
the number of characters for the first of two lines.
pmplots:::str_break("Population prediction CX122341 concentration", 10) #> [1] "Population\nprediction CX122341 concentration"